# tttplots
A modern Python implementation for [Time-to-target Plots](http://mauricio.resende.info/tttplots/).

## Getting Started

```bash
$ pip install tttplots

$ tttplots --help
```

## References
1. Renata M. Aiex, Mauricio G. C. Resende, and Celso C. Ribeiro, **TTTPLOTS: A PERL PROGRAM TO CREATE TIME-TO-TARGET PLOTS**, Oct, 2005.